==> adt-0.0.2.0020-sources.jar: replacer.sh <==
#!/bin/sh
sed -i "s#@profile_active@#$adt_profile_active#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@athena_logger_enable@#$adt_athena_logger_enable#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@lmc_endpoint@#$lmc_endpoint#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/logback-spring-private.xml

sed -i "s#@redis_host@#$adt_redis_host#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@redis_port@#$adt_redis_port#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@redis_password@#$adt_redis_password#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@redis_database@#$adt_redis_database#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml

sed -i "s#@mongodb_uri@#$adt_mongodb_uri#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@mongodb_database@#$adt_mongodb_atmcBkDatabase#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@mongodb_atmcBkDatabase@#$adt_mongodb_atmcBkDatabase#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@mongodb_atmcDataUniformity@#$adt_mongodb_atmcDataUniformity#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@mongodb_atmcHistoryData@#$adt_mongodb_atmcHistoryData#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@mongodb_log_uri@#$adt_mongodb_log_uri#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@mongodb_log_database@#$adt_mongodb_log_database#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@mongodb_agileData_log_uri@#$adt_mongodb_agileData_log_uri#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@mongodb_agileData_log_database@#$adt_mongodb_agileData_log_database#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@mongodb_agileData_log_agileDataPagebase@#$adt_mongodb_agileData_log_agileDataPagebase#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml


sed -i "s#@atmc_dbServer@#$adt_atmc_dbServer#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@atmc_dbName@#$adt_atmc_dbName#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@atmc_dbUser@#$adt_atmc_dbUser#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@atmc_dbPassword@#$adt_atmc_dbPassword#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@dbServer@#$adt_dbServer#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@dbName@#$adt_dbName#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@dbUser@#$adt_dbUser#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@dbPassword@#$adt_dbPassword#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml

sed -i "s#@rabbitmq_host@#$adt_rabbitmq_host#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@rabbitmq_port@#$adt_rabbitmq_port#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml

sed -i "s#@rabbitmq_username@#$adt_rabbitmq_username#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@rabbitmq_password@#$adt_rabbitmq_password#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@rabbitmq_virtual_host@#$adt_rabbitmq_virtual_host#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml

sed -i "s#@iam_uri@#$adt_iam_uri#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@iam_bossUri@#$adt_iam_bossUri#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@iam_cacUri@#$adt_iam_cacUri#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@themeMap_uri@#$adt_themeMap_uri#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@themeMap_rootUri@#$adt_themeMap_rootUri#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@themeMap_dataMapUri@#$adt_themeMap_dataMapUri#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@themeMap_knowledgeGraphUri@#$adt_themeMap_knowledgeGraphUri#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@themeMap_supportPerson@#$adt_themeMap_supportPerson#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@bpm_uri@#$adt_bpm_uri#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@uibot_uri@#$adt_uibot_uri#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@eoc_uri@#$adt_eoc_uri#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@im_uri@#$adt_im_uri#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@taskEngine_uri@#$adt_taskEngine_uri#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@ptm_uri@#$adt_ptm_uri#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@abt_uri@#$adt_abt_uri#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@aim_uri@#$adt_aim_uri#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@aam_uri@#$adt_aam_uri#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@ade_uri@#$adt_ade_uri#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@fileparsing_uri@#$adt_fileparsing_uri#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@semc_uri@#$adt_semc_uri#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@chatBI_uri@#$adt_chatBI_uri#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@chatBI_strategy@#$adt_chatBI_strategy#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@chatBI_gptModel@#$adt_chatBI_gptModel#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@language@#$adt_language#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml

sed -i "s#@tdd_url@#$adt_tdd_url#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@agiledataecho_url@#$adt_agiledataecho_url#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@cac_url@#$adt_cac_url#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@adt_url@#$adt_adt_url#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml


sed -i "s#@apollo_cluster@#$adt_apollo_cluster#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@apollo_meta@#$adt_apollo_meta#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@apollo_namespaces@#$adt_apollo_namespaces#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@loadbalance_enable@#$adt_loadbalance_enable#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@spring.cloud.nacos.discovery.server-addr@#$adt_spring.cloud.nacos.discovery.server-addr#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml

sed -i "s#@xxl_job_admin_addresses@#$adt_xxl_job_admin_addresses#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@xxl_job_accessToken@#$adt_xxl_job_accessToken#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@xxl_job_executor_appname@#$adt_xxl_job_executor_appname#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@xxl_job_executor_address@#$adt_xxl_job_executor_address#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@xxl_job_executor_ip@#$adt_xxl_job_executor_ip#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@xxl_job_executor_port@#$adt_xxl_job_executor_port#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@xxl_job_executor_logpath@#$adt_xxl_job_executor_logpath#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@xxl_job_executor_logretentiondays@#$adt_xxl_job_executor_logretentiondays#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml

sed -i "s#@cost_calculateCostValue@#$adt_cost_calculateCostValue#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml

sed -i "s#@dmc_url@#$adt_dmc_url#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@dmc_account@#$adt_dmc_account#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@dmc_password@#$adt_dmc_password#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@dmc_bucket@#$adt_dmc_bucket#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml

sed -i -E 's/\$\{([^:{}]+)(:[^}]*)?\}/\${adt_\1\2}/g' /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml

cp -r /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml /usr/local/tomcat/webapps/adt/WEB-INF/classes/application.yml
cp -r /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/logback-spring-private.xml /usr/local/tomcat/webapps/adt/WEB-INF/classes/logback-spring.xml

==> adt-0.0.2.0021-sources.jar: replacer.sh <==
#!/bin/sh
sed -i "s#@profile_active@#$adt_profile_active#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@athena_logger_enable@#$adt_athena_logger_enable#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@lmc_endpoint@#$lmc_endpoint#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/logback-spring-private.xml

sed -i "s#@redis_host@#$adt_redis_host#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@redis_port@#$adt_redis_port#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@redis_password@#$adt_redis_password#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@redis_database@#$adt_redis_database#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml

sed -i "s#@mongodb_uri@#$adt_mongodb_uri#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@mongodb_database@#$adt_mongodb_atmcBkDatabase#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@mongodb_atmcBkDatabase@#$adt_mongodb_atmcBkDatabase#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@mongodb_atmcDataUniformity@#$adt_mongodb_atmcDataUniformity#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@mongodb_atmcHistoryData@#$adt_mongodb_atmcHistoryData#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@mongodb_log_uri@#$adt_mongodb_log_uri#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@mongodb_log_database@#$adt_mongodb_log_database#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@mongodb_agileData_log_uri@#$adt_mongodb_agileData_log_uri#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@mongodb_agileData_log_database@#$adt_mongodb_agileData_log_database#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@mongodb_agileData_log_agileDataPagebase@#$adt_mongodb_agileData_log_agileDataPagebase#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml


sed -i "s#@atmc_dbServer@#$adt_atmc_dbServer#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@atmc_dbName@#$adt_atmc_dbName#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@atmc_dbUser@#$adt_atmc_dbUser#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@atmc_dbPassword@#$adt_atmc_dbPassword#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@dbServer@#$adt_dbServer#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@dbName@#$adt_dbName#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@dbUser@#$adt_dbUser#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@dbPassword@#$adt_dbPassword#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml

sed -i "s#@rabbitmq_host@#$adt_rabbitmq_host#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@rabbitmq_port@#$adt_rabbitmq_port#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml

sed -i "s#@rabbitmq_username@#$adt_rabbitmq_username#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@rabbitmq_password@#$adt_rabbitmq_password#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@rabbitmq_virtual_host@#$adt_rabbitmq_virtual_host#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml

sed -i "s#@iam_uri@#$adt_iam_uri#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@iam_bossUri@#$adt_iam_bossUri#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@iam_cacUri@#$adt_iam_cacUri#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@themeMap_uri@#$adt_themeMap_uri#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@themeMap_rootUri@#$adt_themeMap_rootUri#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@themeMap_dataMapUri@#$adt_themeMap_dataMapUri#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@themeMap_knowledgeGraphUri@#$adt_themeMap_knowledgeGraphUri#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@themeMap_supportPerson@#$adt_themeMap_supportPerson#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@bpm_uri@#$adt_bpm_uri#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@uibot_uri@#$adt_uibot_uri#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@eoc_uri@#$adt_eoc_uri#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@im_uri@#$adt_im_uri#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@taskEngine_uri@#$adt_taskEngine_uri#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@ptm_uri@#$adt_ptm_uri#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@abt_uri@#$adt_abt_uri#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@aim_uri@#$adt_aim_uri#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@aam_uri@#$adt_aam_uri#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@ade_uri@#$adt_ade_uri#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@fileparsing_uri@#$adt_fileparsing_uri#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@semc_uri@#$adt_semc_uri#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@chatBI_uri@#$adt_chatBI_uri#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@chatBI_strategy@#$adt_chatBI_strategy#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@chatBI_gptModel@#$adt_chatBI_gptModel#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@language@#$adt_language#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml

sed -i "s#@tdd_url@#$adt_tdd_url#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@agiledataecho_url@#$adt_agiledataecho_url#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@cac_url@#$adt_cac_url#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@adt_url@#$adt_adt_url#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml


sed -i "s#@apollo_cluster@#$adt_apollo_cluster#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@apollo_meta@#$adt_apollo_meta#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@apollo_namespaces@#$adt_apollo_namespaces#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@loadbalance_enable@#$adt_loadbalance_enable#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@nacos_serverAddr@#$adt_nacos_serverAddr#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml

sed -i "s#@xxl_job_admin_addresses@#$adt_xxl_job_admin_addresses#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@xxl_job_accessToken@#$adt_xxl_job_accessToken#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@xxl_job_executor_appname@#$adt_xxl_job_executor_appname#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@xxl_job_executor_address@#$adt_xxl_job_executor_address#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@xxl_job_executor_ip@#$adt_xxl_job_executor_ip#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@xxl_job_executor_port@#$adt_xxl_job_executor_port#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@xxl_job_executor_logpath@#$adt_xxl_job_executor_logpath#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@xxl_job_executor_logretentiondays@#$adt_xxl_job_executor_logretentiondays#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml

sed -i "s#@cost_calculateCostValue@#$adt_cost_calculateCostValue#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml

sed -i "s#@dmc_url@#$adt_dmc_url#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@dmc_account@#$adt_dmc_account#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@dmc_password@#$adt_dmc_password#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml
sed -i "s#@dmc_bucket@#$adt_dmc_bucket#g" /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml

sed -i -E 's/\$\{([^:{}]+)(:[^}]*)?\}/\${adt_\1\2}/g' /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml

cp -r /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/application.yml /usr/local/tomcat/webapps/adt/WEB-INF/classes/application.yml
cp -r /usr/local/tomcat/webapps/adt/WEB-INF/classes/docker/logback-spring-private.xml /usr/local/tomcat/webapps/adt/WEB-INF/classes/logback-spring.xml
